MNE-FASTER: automatic bad channel/epoch/component detection
===========================================================

.. image:: https://zenodo.org/badge/387255460.svg
   :target: https://zenodo.org/badge/latestdoi/387255460

This implements the `FASTER pipeline <https://sourceforge.net/projects/faster/>`_ using `MNE-Python <https://mne.tools>`_.

Nolan H, Whelan R, Reilly RB. FASTER: Fully Automated Statistical Thresholding for EEG artifact Rejection. J Neurosci Methods. 2010 Sep 30;192(1):152-62. doi: `10.1016/j.jneumeth.2010.07.015 <https://doi.org/10.1016/j.jneumeth.2010.07.015>`_. Epub 2010 Jul 21. PMID: 20654646.


Installation
------------

.. code-block:: bash

   pip install https://github.com/wmvanvliet/mne-faster/archive/refs/heads/main.zip


Usage
-----

See the `example <https://github.com/wmvanvliet/mne-faster/blob/main/examples/plot_artifact_correction_with_faster.py>`_
